@@ -45,7 +45,6 @@ describe 'nova::api' do
       it { is_expected.to contain_class('nova::availability_zone') }
 
       it 'configures various stuff' do
-        is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('wsgi/api_paste_config').with_value('api-paste.ini')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with_value('<SERVICE DEFAULT>')
@@ -66,7 +65,7 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/enable_network_quota').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('api/enable_instance_password').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/password_length').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with_value(false)
+        is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('api/instance_list_per_project_cells').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('api/instance_list_cells_batch_strategy').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('api/instance_list_cells_batch_fixed_size').with_value('<SERVICE DEFAULT>')
@@ -157,17 +156,6 @@ describe 'nova::api' do
       it { is_expected.to_not contain_service('nova-api') }
     end
 
-    context 'with custom instance_name_template' do
-      before do
-        params.merge!({
-          :instance_name_template => 'instance-%08x',
-        })
-      end
-      it 'configures instance_name_template' do
-        is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_value('instance-%08x');
-      end
-    end
-
     context 'when running nova API in wsgi compute, and enabling metadata' do
       before do
         params.merge!({ :service_name => 'httpd' })
@@ -288,7 +276,7 @@ describe 'nova::api' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :nova_api_package => 'nova-api',
             :nova_api_service => 'nova-api' }
@@ -298,7 +286,7 @@ describe 'nova::api' do
         end
       end
       it_behaves_like 'nova-api'
-      if facts[:operatingsystem] == 'Debian'
+      if facts[:os]['name'] == 'Debian'
         it_behaves_like 'nova-api on Debian'
       end
     end
