@@ -35,14 +35,11 @@ describe 'nova::compute::ironic' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({
-          :fqdn           => 'some.host.tld',
-          :concat_basedir => '/var/lib/puppet/concat'
-        }))
+        facts.merge!(OSDefaults.get_facts())
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
             {}
         when 'RedHat'
