@@ -51,6 +51,10 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('host-model')}
       it { is_expected.to contain_nova_config('libvirt/cpu_models').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_management').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_management_strategy').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_governor_low').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_governor_high').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/snapshots_directory').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_ensure('absent')}
@@ -77,6 +81,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/max_queues').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/wait_soft_reboot_seconds').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/tb_cache_size').with_value('<SERVICE DEFAULT>')}
     end
 
     describe 'with params' do
@@ -87,6 +92,10 @@ describe 'nova::compute::libvirt' do
           :cpu_mode                                   => 'host-passthrough',
           :cpu_models                                 => ['kvm64', 'qemu64'],
           :cpu_model_extra_flags                      => 'pcid',
+          :cpu_power_management                       => false,
+          :cpu_power_management_strategy              => 'cpu_state',
+          :cpu_power_governor_low                     => 'powersave',
+          :cpu_power_governor_high                    => 'performance',
           :snapshot_image_format                      => 'raw',
           :snapshots_directory                        => '/var/lib/nova/snapshots',
           :disk_cachemodes                            => ['file=directsync','block=none'],
@@ -113,14 +122,10 @@ describe 'nova::compute::libvirt' do
           :swtpm_enabled                              => true,
           :swtpm_user                                 => 'libvirt',
           :swtpm_group                                => 'libvirt',
-          :log_outputs                                => '1:file:/var/log/libvirt/libvirtd.log',
-          :log_filters                                => '1:qemu',
-          :tls_priority                               => 'NORMAL:-VERS-SSL3.0',
-          :ovs_timeout                                => 10,
           :max_queues                                 => 4,
           :num_memory_encrypted_guests                => 255,
-          :modular_libvirt                            => true,
           :wait_soft_reboot_seconds                   => 120,
+          :tb_cache_size                              => 32,
         }
       end
 
@@ -134,6 +139,10 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('host-passthrough')}
       it { is_expected.to contain_nova_config('libvirt/cpu_models').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_value('pcid')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_management').with_value(false)}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_management_strategy').with_value('cpu_state')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_governor_low').with_value('powersave')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_power_governor_high').with_value('performance')}
       it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('raw')}
       it { is_expected.to contain_nova_config('libvirt/snapshots_directory').with_value('/var/lib/nova/snapshots')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_value('file=directsync,block=none')}
@@ -159,6 +168,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/max_queues').with_value(4)}
       it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value(255)}
       it { is_expected.to contain_nova_config('libvirt/wait_soft_reboot_seconds').with_value(120)}
+      it { is_expected.to contain_nova_config('libvirt/tb_cache_size').with_value(32)}
 
       it {
         is_expected.to contain_service('libvirt').with(
@@ -193,20 +203,21 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_value('pcid')}
     end
 
-    describe 'with qcow2 as snapshot_image_format' do
+    describe 'with hw_machine_type set by array' do
       let :params do
-        { :snapshot_image_format => 'qcow2' }
+        { :hw_machine_type => ['x86_64=machinetype1', 'armv7l=machinetype2'] }
       end
-
-      it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('qcow2')}
+      it { is_expected.to contain_nova_config('libvirt/hw_machine_type').with_value('x86_64=machinetype1,armv7l=machinetype2')}
     end
 
-    describe 'with qemu as virt_type' do
+    describe 'with hw_machine_type set by hash' do
       let :params do
-        { :virt_type => 'qemu' }
+        { :hw_machine_type => {
+          'x86_64' => 'machinetype1',
+          'armv7l' => 'machinetype2'
+        } }
       end
-
-      it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('none')}
+      it { is_expected.to contain_nova_config('libvirt/hw_machine_type').with_value('x86_64=machinetype1,armv7l=machinetype2')}
     end
 
     describe 'with migration_support enabled' do
@@ -364,7 +375,7 @@ describe 'nova::compute::libvirt' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      case facts[:osfamily]
+      case facts[:os]['family']
       when 'Debian'
         it_behaves_like 'debian-nova-compute-libvirt'
       when 'RedHat'
