@@ -326,16 +326,6 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit_period').with_ensure('absent') }
     end
 
-    context 'with instance_usage_audit parameter and wrong period' do
-      let :params do
-        { :instance_usage_audit        => true,
-          :instance_usage_audit_period => 'fake', }
-      end
-
-      it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit').with_ensure('absent') }
-      it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit_period').with_ensure('absent') }
-    end
-
     context 'with instance_usage_audit parameter and period' do
       let :params do
         { :instance_usage_audit        => true,
@@ -355,7 +345,7 @@ describe 'nova::compute' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts())
       end
-      case facts[:osfamily]
+      case facts[:os]['family']
       when 'Debian'
         let (:platform_params) do
           {
@@ -369,24 +359,11 @@ describe 'nova::compute' do
         let (:platform_params) do
           {
             :nova_compute_package => 'openstack-nova-compute',
-            :nova_compute_service => 'openstack-nova-compute'
+            :nova_compute_service => 'openstack-nova-compute',
+            :mkisofs_package      => 'xorriso',
+            :mkisofs_cmd          => 'mkisofs'
           }
         end
-        if facts[:operatingsystemmajrelease].to_i >= 9
-          before do
-            platform_params.merge!({
-              :mkisofs_package => 'xorriso',
-              :mkisofs_cmd     => 'mkisofs'
-            })
-          end
-        else
-          before do
-            platform_params.merge!({
-              :mkisofs_package => 'genisoimage',
-              :mkisofs_cmd     => '<SERVICE DEFAULT>'
-            })
-          end
-        end
       end
       it_behaves_like 'nova-compute'
     end
