@@ -9,7 +9,7 @@ describe 'nova::db::mysql_api' do
     end
 
     let :required_params do
-      { :password => "qwerty" }
+      { :password => "novapass" }
     end
 
     context 'with only required params' do
@@ -17,23 +17,21 @@ describe 'nova::db::mysql_api' do
         required_params
       end
       it { is_expected.to contain_openstacklib__db__mysql('nova_api').with(
-        :user          => 'nova_api',
-        :password_hash => '*AA1420F182E88B9E5F874F6FBE7459291E8F4601',
-        :charset       => 'utf8',
-        :collate       => 'utf8_general_ci',
+        :user     => 'nova_api',
+        :password => 'novapass',
+        :charset  => 'utf8',
+        :collate  => 'utf8_general_ci',
       )}
     end
 
     context 'overriding allowed_hosts param to array' do
       let :params do
-        { :password       => 'novapass',
-          :allowed_hosts  => ['127.0.0.1','%'],
-        }.merge(required_params)
+        { :allowed_hosts  => ['127.0.0.1','%'] }.merge(required_params)
       end
 
       it { is_expected.to contain_openstacklib__db__mysql('nova_api').with(
         :user          => 'nova_api',
-        :password_hash => '*AA1420F182E88B9E5F874F6FBE7459291E8F4601',
+        :password      => 'novapass',
         :charset       => 'utf8',
         :collate       => 'utf8_general_ci',
         :allowed_hosts => ['127.0.0.1','%'],
@@ -42,14 +40,12 @@ describe 'nova::db::mysql_api' do
 
     context 'overriding allowed_hosts param to string' do
       let :params do
-        { :password       => 'novapass2',
-          :allowed_hosts  => '192.168.1.1',
-        }.merge(required_params)
+        { :allowed_hosts  => '192.168.1.1' }.merge(required_params)
       end
 
       it { is_expected.to contain_openstacklib__db__mysql('nova_api').with(
         :user          => 'nova_api',
-        :password_hash => '*AA1420F182E88B9E5F874F6FBE7459291E8F4601',
+        :password      => 'novapass',
         :charset       => 'utf8',
         :collate       => 'utf8_general_ci',
         :allowed_hosts => '192.168.1.1',
@@ -58,9 +54,7 @@ describe 'nova::db::mysql_api' do
 
     context 'when overriding charset' do
       let :params do
-        { :password => 'novapass',
-          :charset => 'latin1',
-        }.merge(required_params)
+        { :charset => 'latin1' }.merge(required_params)
       end
 
       it { is_expected.to contain_openstacklib__db__mysql('nova_api').with(
