@@ -32,8 +32,9 @@ describe 'nova::db::postgresql_api' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :os_workers     => 8,
-          :concat_basedir => '/var/lib/puppet/concat'
+          # puppet-postgresql requires the service_provider fact provided by
+          # puppetlabs-postgresql.
+          :service_provider => 'systemd'
         }))
       end
 
