@@ -25,36 +25,36 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
       end
 
-      it { is_expected.to contain_exec('networking-refresh').with(
-        :command     => '/sbin/ifdown -a ; /sbin/ifup -a',
-        :refreshonly => true
-      )}
-
       it 'does not configure auth_strategy' do
-        is_expected.not_to contain_nova_config('api/auth_strategy')
+        is_expected.to contain_nova_config('api/auth_strategy').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures rabbit' do
         is_expected.to contain_oslo__messaging__default('nova_config').with(
-          :transport_url        => '<SERVICE DEFAULT>',
-          :rpc_response_timeout => '<SERVICE DEFAULT>',
-          :control_exchange     => '<SERVICE DEFAULT>',
+          :executor_thread_pool_size => '<SERVICE DEFAULT>',
+          :transport_url             => '<SERVICE DEFAULT>',
+          :rpc_response_timeout      => '<SERVICE DEFAULT>',
+          :control_exchange          => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
-          :rabbit_use_ssl              => '<SERVICE DEFAULT>',
-          :heartbeat_timeout_threshold => '<SERVICE DEFAULT>',
-          :heartbeat_rate              => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread        => '<SERVICE DEFAULT>',
-          :kombu_reconnect_delay       => '<SERVICE DEFAULT>',
-          :kombu_failover_strategy     => '<SERVICE DEFAULT>',
-          :amqp_durable_queues         => '<SERVICE DEFAULT>',
-          :kombu_compression           => '<SERVICE DEFAULT>',
-          :kombu_ssl_ca_certs          => '<SERVICE DEFAULT>',
-          :kombu_ssl_certfile          => '<SERVICE DEFAULT>',
-          :kombu_ssl_keyfile           => '<SERVICE DEFAULT>',
-          :kombu_ssl_version           => '<SERVICE DEFAULT>',
-          :rabbit_ha_queues            => '<SERVICE DEFAULT>',
-          :rabbit_retry_interval       => '<SERVICE DEFAULT>',
+          :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
+          :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
+          :heartbeat_rate                  => '<SERVICE DEFAULT>',
+          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+          :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
+          :kombu_failover_strategy         => '<SERVICE DEFAULT>',
+          :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :kombu_compression               => '<SERVICE DEFAULT>',
+          :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile               => '<SERVICE DEFAULT>',
+          :kombu_ssl_version               => '<SERVICE DEFAULT>',
+          :rabbit_ha_queues                => '<SERVICE DEFAULT>',
+          :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+          :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+          :rabbit_retry_interval           => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__amqp('nova_config').with(
           :server_request_prefix => '<SERVICE DEFAULT>',
@@ -84,9 +84,12 @@ describe 'nova' do
         is_expected.to contain_oslo__concurrency('nova_config').with(
           :lock_path => platform_params[:lock_path]
         )
-        is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
+        is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('notifications/notification_format').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('notifications/notify_on_state_change').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
-        is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
+        is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/periodic_fuzzy_delay').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('vif_plug_ovs/ovsdb_connection').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/long_rpc_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
@@ -95,12 +98,13 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/initial_cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/initial_ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/initial_disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(false)
+        is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('console/ssl_ciphers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_value('<SERVICE DEFAULT>')
       end
 
     end
@@ -113,6 +117,7 @@ describe 'nova' do
           :rpc_response_timeout                    => '30',
           :long_rpc_timeout                        => '1800',
           :control_exchange                        => 'nova',
+          :executor_thread_pool_size               => 64,
           :rabbit_use_ssl                          => true,
           :rabbit_heartbeat_timeout_threshold      => '60',
           :rabbit_heartbeat_rate                   => '10',
@@ -125,6 +130,10 @@ describe 'nova' do
           :kombu_ssl_keyfile                       => '/etc/key',
           :kombu_ssl_version                       => 'TLSv1',
           :rabbit_ha_queues                        => true,
+          :rabbit_quorum_queue                     => true,
+          :rabbit_quorum_delivery_limit            => 3,
+          :rabbit_quorum_max_memory_length         => 5,
+          :rabbit_quorum_max_memory_bytes          => 1073741824,
           :rabbit_retry_interval                   => '1',
           :amqp_idle_timeout                       => '60',
           :amqp_trace                              => true,
@@ -135,7 +144,7 @@ describe 'nova' do
           :amqp_password                           => 'password',
           :lock_path                               => '/var/locky/path',
           :state_path                              => '/var/lib/nova2',
-          :service_down_time                       => '120',
+          :service_down_time                       => '60',
           :auth_strategy                           => 'foo',
           :ensure_package                          => '2012.1.1-15.el6',
           :host                                    => 'test-001.example.org',
@@ -143,14 +152,12 @@ describe 'nova' do
           :notification_driver                     => 'ceilometer.compute.nova_notifier',
           :notification_topics                     => 'openstack',
           :notification_format                     => 'unversioned',
-          :report_interval                         => '60',
+          :report_interval                         => '10',
+          :periodic_fuzzy_delay                    => '61',
           :ovsdb_connection                        => 'tcp:127.0.0.1:6640',
-          :upgrade_level_cells                     => '1.0.0',
           :upgrade_level_cert                      => '1.0.0',
           :upgrade_level_compute                   => '1.0.0',
           :upgrade_level_conductor                 => '1.0.0',
-          :upgrade_level_intercell                 => '1.0.0',
-          :upgrade_level_network                   => '1.0.0',
           :upgrade_level_scheduler                 => '1.0.0',
           :purge_config                            => false,
           :my_ip                                   => '192.0.2.1',
@@ -160,7 +167,7 @@ describe 'nova' do
           :console_ssl_ciphers                     => 'kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES',
           :console_ssl_minimum_version             => 'tlsv1_2',
           :dhcp_domain                             => 'foo',
-
+          :instance_name_template                  => 'instance-%08x',
         }
       end
 
@@ -184,24 +191,29 @@ describe 'nova' do
 
       it 'configures rabbit' do
         is_expected.to contain_oslo__messaging__default('nova_config').with(
-          :transport_url        => 'rabbit://rabbit_user:password@localhost:5673',
-          :rpc_response_timeout => '30',
-          :control_exchange     => 'nova',
+          :executor_thread_pool_size => 64,
+          :transport_url             => 'rabbit://rabbit_user:password@localhost:5673',
+          :rpc_response_timeout      => '30',
+          :control_exchange          => 'nova',
         )
         is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
-          :rabbit_use_ssl              => true,
-          :heartbeat_timeout_threshold => '60',
-          :heartbeat_rate              => '10',
-          :heartbeat_in_pthread        => true,
-          :kombu_reconnect_delay       => '5.0',
-          :amqp_durable_queues         => true,
-          :kombu_compression           => 'gzip',
-          :kombu_ssl_ca_certs          => '/etc/ca.cert',
-          :kombu_ssl_certfile          => '/etc/certfile',
-          :kombu_ssl_keyfile           => '/etc/key',
-          :kombu_ssl_version           => 'TLSv1',
-          :rabbit_ha_queues            => true,
-          :rabbit_retry_interval       => '1',
+          :rabbit_use_ssl                  => true,
+          :heartbeat_timeout_threshold     => '60',
+          :heartbeat_rate                  => '10',
+          :heartbeat_in_pthread            => true,
+          :kombu_reconnect_delay           => '5.0',
+          :amqp_durable_queues             => true,
+          :kombu_compression               => 'gzip',
+          :kombu_ssl_ca_certs              => '/etc/ca.cert',
+          :kombu_ssl_certfile              => '/etc/certfile',
+          :kombu_ssl_keyfile               => '/etc/key',
+          :kombu_ssl_version               => 'TLSv1',
+          :rabbit_ha_queues                => true,
+          :rabbit_quorum_queue             => true,
+          :rabbit_quorum_delivery_limit    => 3,
+          :rabbit_quorum_max_memory_length => 5,
+          :rabbit_quorum_max_memory_bytes  => 1073741824,
+          :rabbit_retry_interval           => '1',
         )
         is_expected.to contain_oslo__messaging__amqp('nova_config').with(
           :idle_timeout  => '60',
@@ -228,13 +240,13 @@ describe 'nova' do
       end
 
       it 'configures upgrade_levels' do
-        is_expected.to contain_nova_config('upgrade_levels/cells').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/cert').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/compute').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/conductor').with_value('1.0.0')
-        is_expected.to contain_nova_config('upgrade_levels/intercell').with_value('1.0.0')
-        is_expected.to contain_nova_config('upgrade_levels/network').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/scheduler').with_value('1.0.0')
+
+        is_expected.to contain_nova_config('upgrade_levels/cells').with_ensure('absent')
+        is_expected.to contain_nova_config('upgrade_levels/intercell').with_ensure('absent')
       end
 
       it 'configures various things' do
@@ -242,9 +254,10 @@ describe 'nova' do
         is_expected.to contain_oslo__concurrency('nova_config').with(
           :lock_path => '/var/locky/path'
         )
-        is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('120')
+        is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
         is_expected.to contain_nova_config('notifications/notification_format').with_value('unversioned')
-        is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
+        is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
+        is_expected.to contain_nova_config('DEFAULT/periodic_fuzzy_delay').with_value('61')
         is_expected.to contain_nova_config('vif_plug_ovs/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
         is_expected.to contain_nova_config('DEFAULT/long_rpc_timeout').with_value('1800')
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(true)
@@ -253,6 +266,7 @@ describe 'nova' do
         is_expected.to contain_nova_config('console/ssl_ciphers').with_value('kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES')
         is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('tlsv1_2')
         is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('foo')
+        is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_value('instance-%08x');
       end
 
       context 'with multiple notification_driver' do
@@ -264,16 +278,6 @@ describe 'nova' do
       end
     end
 
-    context 'with wrong notify_on_state_change parameter' do
-      let :params do
-        { :notify_on_state_change => 'vm_status' }
-      end
-
-      it 'configures database' do
-        is_expected.to contain_nova_config('notifications/notify_on_state_change').with_ensure('absent')
-      end
-    end
-
     context 'with notify_on_state_change parameter' do
       let :params do
         { :notify_on_state_change => 'vm_state' }
@@ -335,18 +339,28 @@ describe 'nova' do
       end
     end
 
-    context 'with ssh private key' do
-      let :params do
-        {
-          :nova_private_key => {'type' => 'ssh-rsa',
-                                'key'  => 'keydata'}
-        }
-      end
+    {
+      'ssh-rsa'     => 'id_rsa',
+      'ssh-dsa'     => 'id_dsa',
+      'ssh-ecdsa'   => 'id_ecdsa',
+      'ssh-ed25519' => 'id_ed25519'
+    }.each do |keytype, keyname|
+      context "with ssh private key(#{keytype})" do
+        let :params do
+          {
+            :nova_private_key => {'type' => keytype,
+                                  'key'  => 'keydata'}
+          }
+        end
 
-      it 'should install ssh private key' do
-        is_expected.to contain_file('/var/lib/nova/.ssh/id_rsa').with(
-          :content => 'keydata'
-        )
+        it 'should install ssh private key' do
+          is_expected.to contain_file("/var/lib/nova/.ssh/#{keyname}").with(
+            :content => 'keydata',
+            :mode    => '0600',
+            :owner   => 'nova',
+            :group   => 'nova',
+          )
+        end
       end
     end
 
@@ -466,6 +480,14 @@ describe 'nova' do
       it { is_expected.to contain_nova_config('DEFAULT/initial_disk_allocation_ratio').with_value(3.0) }
     end
 
+    context 'with array used for console_ssl_ciphers' do
+      let :params do
+        {
+          :console_ssl_ciphers => ['kEECDH+aECDSA+AES', 'kEECDH+AES+aRSA', 'kEDH+aRSA+AES']
+        }
+      end
+      it {is_expected.to contain_nova_config('console/ssl_ciphers').with_value('kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES') }
+    end
   end
 
 
@@ -477,7 +499,7 @@ describe 'nova' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      case facts[:osfamily]
+      case facts[:os]['family']
       when 'Debian'
         let (:platform_params) do
           { :nova_common_package => 'nova-common',
