@@ -12,8 +12,8 @@ describe 'nova::scheduler::filter' do
       it { is_expected.to contain_nova_config('filter_scheduler/host_subset_size').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/max_io_ops_per_host').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/max_instances_per_host').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('filter_scheduler/available_filters').with_value(['nova.scheduler.filters.all_filters']) }
-      it { is_expected.to contain_nova_config('filter_scheduler/weight_classes').with_value('nova.scheduler.weights.all_weighers') }
+      it { is_expected.to contain_nova_config('filter_scheduler/available_filters').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('filter_scheduler/weight_classes').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/isolated_images').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/isolated_hosts').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/enabled_filters').with_value('<SERVICE DEFAULT>') }
@@ -26,6 +26,8 @@ describe 'nova::scheduler::filter' do
       it { is_expected.to contain_nova_config('filter_scheduler/soft_anti_affinity_weight_multiplier').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/build_failure_weight_multiplier').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/cross_cell_move_weight_multiplier').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('filter_scheduler/hypervisor_version_weight_multiplier').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('filter_scheduler/num_instances_weight_multiplier').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/shuffle_best_same_weighed_hosts').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/restrict_isolated_hosts_to_isolated_images').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/aggregate_image_properties_isolation_namespace').with_value('<SERVICE DEFAULT>') }
@@ -39,14 +41,14 @@ describe 'nova::scheduler::filter' do
     context 'when overriding params' do
       let :params do
         {
-          :scheduler_host_subset_size           => '3',
+          :host_subset_size                     => '3',
           :max_io_ops_per_host                  => '16',
           :max_instances_per_host               => '100',
           :isolated_images                      => ['ubuntu1','centos2'],
           :isolated_hosts                       => ['192.168.1.2','192.168.1.3'],
-          :scheduler_enabled_filters            => ['RetryFilter','AvailabilityZoneFilter'],
-          :scheduler_available_filters          => ['nova_filter1','nova_filter2'],
-          :scheduler_weight_classes             => 'nova.scheduler.weights.compute.BuildFailureWeigher',
+          :enabled_filters                      => ['RetryFilter','AvailabilityZoneFilter'],
+          :available_filters                    => ['nova_filter1','nova_filter2'],
+          :weight_classes                       => 'nova.scheduler.weights.compute.BuildFailureWeigher',
           :track_instance_changes               => true,
           :ram_weight_multiplier                => 10,
           :cpu_weight_multiplier                => 20,
@@ -56,6 +58,8 @@ describe 'nova::scheduler::filter' do
           :soft_anti_affinity_weight_multiplier => 60,
           :build_failure_weight_multiplier      => 100,
           :cross_cell_move_weight_multiplier    => 1000,
+          :hypervisor_version_weight_multiplier => 70,
+          :num_instances_weight_multiplier      => 0,
           :shuffle_best_same_weighed_hosts      => true,
         }
       end
@@ -72,6 +76,8 @@ describe 'nova::scheduler::filter' do
       it { is_expected.to contain_nova_config('filter_scheduler/soft_anti_affinity_weight_multiplier').with_value(60) }
       it { is_expected.to contain_nova_config('filter_scheduler/build_failure_weight_multiplier').with_value(100) }
       it { is_expected.to contain_nova_config('filter_scheduler/cross_cell_move_weight_multiplier').with_value(1000) }
+      it { is_expected.to contain_nova_config('filter_scheduler/hypervisor_version_weight_multiplier').with_value(70) }
+      it { is_expected.to contain_nova_config('filter_scheduler/num_instances_weight_multiplier').with_value(0) }
       it { is_expected.to contain_nova_config('filter_scheduler/shuffle_best_same_weighed_hosts').with_value(true) }
       it { is_expected.to contain_nova_config('filter_scheduler/isolated_images').with_value('ubuntu1,centos2') }
       it { is_expected.to contain_nova_config('filter_scheduler/isolated_hosts').with_value('192.168.1.2,192.168.1.3') }
@@ -81,15 +87,12 @@ describe 'nova::scheduler::filter' do
 
     context 'when overriding params with empty arrays' do
       let :params do
-        { :isolated_images                      => [],
-          :isolated_hosts                       => [],
-          :scheduler_available_filters          => [],
-          :scheduler_enabled_filters            => [],
+        {
+          :available_filters => [],
+          :enabled_filters   => [],
         }
       end
 
-      it { is_expected.to contain_nova_config('filter_scheduler/isolated_images').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('filter_scheduler/isolated_hosts').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/available_filters').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('filter_scheduler/enabled_filters').with_value('<SERVICE DEFAULT>') }
     end
